From b7a2f577ef1faa791df59a0890db37bf80abce8b Mon Sep 17 00:00:00 2001
From: Magnus Hallin <mhallin@fastmail.com>
Date: Sun, 26 Feb 2017 12:56:07 +0100
Subject: [PATCH] Add more default value documentation

---
 src/macros/object.rs | 14 +++++++++++---
 1 file changed, 11 insertions(+), 3 deletions(-)

diff --git a/src/macros/object.rs b/src/macros/object.rs
index 4fcfd1f3..32ad0bf0 100644
--- a/src/macros/object.rs
+++ b/src/macros/object.rs
@@ -215,9 +215,17 @@ default value, _or_ make the type into an `Option<>`, the argument becomes
 optional. For example:
 
 ```text
-arg_name: String               -- required
-arg_name: Option<String>       -- optional, None if unspecified
-arg_name = "default": String   -- optional "default" if unspecified
+arg_name: i64               -- required
+arg_name: Option<i64>       -- optional, None if unspecified
+arg_name = 123: i64         -- optional, "123" if unspecified
+```
+
+Due to some syntactical limitations in the macros, you must parentesize more
+complex default value expressions:
+
+```text
+arg_name = (Point { x: 1, y: 2 }): Point
+arg_name = ("default".to_owned()): String
 ```
 
 [1]: struct.Executor.html